package de.cnam.jemina.config;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.net.URISyntaxException;
import java.util.Properties;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Zum Laden der Konfigurationen
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class ConfigManager {
    // Propeties Dateiname
    protected static final String FILENAME = "config.properties";

    // Logging:
    private static final Logger ivLog = LoggerFactory.getLogger(ConfigManager.class);

    private static ConfigManager ivInstance = null;
    private Properties ivProp = null;

    /**
     * Singleton
     */
    private ConfigManager() {
        super();
        init();
    }

    /**
     * Liefert eine Singleton-Instanz dieser Klasse
     * @return
     */
    public static synchronized ConfigManager getInstance() {
        if (ivInstance == null) {
            ivInstance = new ConfigManager();
        }

        return ivInstance;
    }

    /**
     * Liefert die Konfiguration
     * @param pvName
     * @return Liefert <b>null</b> wenn es einen Fehler gab oder die Konfiguration nicht gefunden wurde
     */
    public String getConfig(String pvName) {
        if (ivProp == null) {
            return null;
        }
        return ivProp.getProperty(pvName);
    }

    /**
     * L&auml;dt die Konfigurationsdatei
     */
    private void init() {
        if (ivLog.isInfoEnabled()) {
            ivLog.info("Inizalisiere ConfigManager");
        }

        ivProp = new Properties();
        try {
            File lvFile = new File(ConfigManager.class.getClassLoader().getResource(FILENAME).toURI());
            if (ivLog.isInfoEnabled()) {
                ivLog.info("Lade Konfigurationsdatei: " + lvFile.getAbsolutePath());
            }
            ivProp.load(new FileInputStream(lvFile));
        } catch (URISyntaxException | IOException ex) {
            ivLog.error("Fehler beim laden der Konfigurationsdatei", ex);
        }
    }

}