package de.cnam.jemina.config;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.net.URISyntaxException;
import java.util.Properties;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Zum Laden der SQL-Befehle
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class SqlManager {
    
    // Propeties Dateiname
    protected static final String FILENAME = "sqls.properties";
    
    // Logging:
    private static final Logger ivLog = LoggerFactory.getLogger(SqlManager.class);
    
    private static SqlManager ivInstance = null;
    private Properties ivProp = null;

    /**
     * Singleton
     */
    private SqlManager() {
        super();
        init();
    }
    
    /**
     * Liefert eine Singleton-Instanz dieser Klasse
     * @return
     */
    public static synchronized SqlManager getInstance() {
        if (ivInstance == null) {
            ivInstance = new SqlManager();
        }

        return ivInstance;
    }

    /**
     * Liefert den SQL Befehl
     * @param pvName
     * @return Liefert <b>null</b> wenn es einen Fehler gab oder wenn der SQL Befehl nicht gefunden wurde
     */
    public String getSql(String pvName) {
        if (ivProp == null) {
            return null;
        }
        return ivProp.getProperty(pvName);
    }

    /**
     * L&auml;dt die Konfigurationsdatei
     */
    private void init() {
        if (ivLog.isInfoEnabled()) {
            ivLog.info("Inizalisiere SqlManager");
        }

        ivProp = new Properties();
        try {
            File lvFile = new File(SqlManager.class.getClassLoader().getResource(FILENAME).toURI());
            if (ivLog.isInfoEnabled()) {
                ivLog.info("Lade Konfigurationsdatei: " + lvFile.getAbsolutePath());
            }
            ivProp.load(new FileInputStream(lvFile));
        } catch (URISyntaxException | IOException ex) {
            ivLog.error("Fehler beim laden der Konfigurationsdatei", ex);
        }
    }

}
