package de.cnam.jemina.entrypoint;

import com.vaadin.ui.Window;
import com.vaadin.ui.Window.Notification;
import de.cnam.jemina.extern.auth.IUser;
import de.cnam.jemina.persistents.IPersistent;
import de.cnam.jemina.ui.controlls.IControll;
import java.util.Map;

/**
 * Interface f&uuml;r die Applikations-Klasse</br>
 * Diese wird von den {@link IControll Controller-Klassen} angesprochen.
 * @author CNAM Team (Nadine, Mike, Jens)
 * @since 22.01.2013
 */
public interface IJeminaApplication {
    
    /**
     * Diese Methode weisst die Applikation an, ein bestimmtes Modul (View) 
     * zu &ouml;ffnen. Es kann auch ein Objekt an dieses Modul &uuml;bergeben
     * werden, sowie zus&auml;tzliche Parameter.
     * @param name Name des Moduls (see {@link IControll#getName()})
     * @param obj Objekt, welches an das Modul &uuml;bergeben werden soll (kann <b>null</b> sein)
     * @param additionalParameters Zus&auml;tzliche Parameter, die an das Modul &uuml;bergeben werden (kann <b>null</b> sein)
     */
    public void openModul(String name, Object obj, Map additionalParameters);

    /**
     * Liefert den aktuell angemeldetn {@link IUser User}.<br/>
     * Liefert <b>null</b> wenn der Anwender noch nicht angemeldet hat (Gast).
     * @return <b>null</b> oder ein {@link IUser} Objekt
     */
    public IUser getUser();
    
    /**
     * Liefert die {@link IPersistent Persistenzklasse}
     * @return 
     */
    public IPersistent getPersistentObj();
    
    /**
     * Zeigt dem Anwender eine Meldung an.
     * @param txt Text der angezeigt werden soll
     * @param type Art der Meldung (siehe {@link Notification})
     */
    public void showNotification(String txt, int type);
    
    /**
     * Zeigt dem Anwender eine Fehlermeldung
     * @param txt Text der angezeigt werden soll
     */
    public void showError(String txt);
    
    /**
     * Zeigt dem Anwender eine Infomeldung
     * @param txt Text der angezeigt werden soll
     */
    public void showInfo(String txt);
    
    /**
     * Zeigt dem Anwender eine Warnung an
     * @param txt 
     */
    public void showWarning(String txt);
    
    /**
     * Diese Methode kann genutzt werden, um die An- bzw. Abmeldung
     * eines Anwenders, der Anwendung mitzuteilen.<br/>
     * F&uuml;r die <b>Abmeldung</b> eines Anwenders einfach <b>null</b>
     * &uuml;bergeben
     * @param user <b>null</b> wenn sich der Anwender abgemeldet hat, ansonsten das User-Objekt
     */
    public void notifyLogin(IUser user);
    
    /**
     * Liefert das {@link Window} Objekt aus Vaadin
     * @return 
     */
    public Window getVaadinWindow();
}
