package de.cnam.jemina.migration;

import au.com.bytecode.opencsv.CSVReader;
import de.cnam.jemina.extern.auth.IUser;
import de.cnam.jemina.objects.Buch;
import de.cnam.jemina.persistents.IPersistent;
import de.cnam.jemina.stub.auth.User;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Diese Klasse dient zur Migration der Altdaten, die als CSV vorliegen.
 *
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public abstract class CsvReader {

    public static final String IMPORT_USER = "import";
    
    // Logging:
    private static final Logger log = LoggerFactory.getLogger(CsvReader.class);

    /**
     * <p>Liest den &uuml;bergebenen B&uuml;cherbestand ein, und schreibt diese
     * in die Persistensschicht.</p> <p>Die B&uuml;cher CSV Daten sind mit einem
     * <b>Strichpunkt</b> getrennt. String stehen in <b>doppelten
     * Anf&uuml;hrungsstrichen</b>.</p>
     *
     * <p>Die erste Zeile wird &uuml;bersprungen!</p> <br/>
     *
     * <b><u>Aufbaue der CSV:</u></b>: <ul> <li><b>Nr</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Serie</b> (<i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Titel</b></li> <li><b>Link</b> <i>(wird
     * nicht &uuml;bernommen)</i></li> <li><b>Autor</b></li> <li><b>Link</b>
     * <i>(wird nicht &uuml;bernommen)</i></li> <li><b>Genre_kurz</b> <i>(wird
     * nicht &uuml;bernommen)</i></li> <li><b>Genre</b></li> <li><b>Sprache</b>
     * <i>(wird nicht &uuml;bernommen)</i></li> <li><b>Datei</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Seiten</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Verlag</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>&Uuml;bersetzer</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Illustrator</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Herausgeber</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>ASIN</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>ISBN</b></li> <li><b>OriginalTitel</b>
     * <i>(wird nicht &uuml;bernommen)</i></li> <li><b>Erstausgabe</b> <i>(wird
     * nicht &uuml;bernommen)</i></li> <li><b>R</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>DRM</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Kaufdatum</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Grosser Bildschirm</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>OriginalAmazonTitel</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> <li><b>Lizenzen</b> <i>(wird nicht
     * &uuml;bernommen)</i></li> </ul>
     *
     * @param filename Dateiname
     * @param db Persitensschicht in die die Daten geschrieben werden sollen
     * @throws FileNotFoundException
     * @throws IOException
     */
    public static void insertBooks(File filename, IPersistent db) throws FileNotFoundException, IOException {
        if (filename == null) {
            throw new FileNotFoundException("Keine Datei uebergeben!");
        }

        // Log
        if (log.isInfoEnabled()) {
            log.info("CSV Import von {} wird gestartet.", filename.getAbsolutePath());
        }

        CSVReader reader = new CSVReader(new FileReader(filename), ';', '\"');
        int counter = 0;
        String[] nextLine;
        // Titel = [2]
        // Autor = [4]
        // Genre = [6]
        // ISBN = [15]
        Buch buch = null;
        IUser user = new User("system", null, IUser.ROLLE.MITARBEITER, null);
        List<String[]> csvLines = reader.readAll();
        final int lines = csvLines.size();
        if (lines > 1) {
            for (int i = 1, m = lines; i < m; i++) {
                nextLine = csvLines.get(i);
                try {
                    buch = new Buch(nextLine[15], nextLine[4], nextLine[2], nextLine[4]);
                    db.insert(buch, user);
                    counter++;
                    if (log.isInfoEnabled()) {
                        log.info("Gespeichert {}", buch);
                    }
                } catch (Exception ex) {
                    log.error("Konnte nicht speichern: {}  Grund: {}", buch, ex.getLocalizedMessage());
                }
            }
            // Log
            if (log.isInfoEnabled()) {
                log.info("Es wurden {} Datensaetze importiert. Fehlerhafte Daten: {}", counter, lines-1-counter);
            }
        }
    }
    
    /**
     * Laedt die Migrationsdaten in die Datenbank
     * @param args 
     */
//    public static void main(String[] args) {
//        try {
//            // DB Starten
//            EmbeddedHsqlServer server = EmbeddedHsqlServer.getInstance();            
//            
//            File f = new File(CsvReader.class.getClassLoader().getResource("buecher.csv").toURI());
//            insertBooks(f, server.getConnection());
//                        
//            server.stopDatabase();
//        } catch (Exception ex) {
//            log.error("Fehler beim Import", ex);
//        }
//    }
}
