package de.cnam.jemina.ui.views.impl;

import com.vaadin.event.MouseEvents;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Component;
import com.vaadin.ui.CustomComponent;
import com.vaadin.ui.Embedded;
import com.vaadin.ui.Label;
import com.vaadin.ui.VerticalLayout;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.resource.ImgThemeResource;
import de.cnam.jemina.ui.components.SearchComponent;

/**
 * Die Startseite
 * 
 * @author CNAM Team (Nadine, Mike, Jens)
 * @since 19.01.2013
 */
public class StartpageView extends CustomComponent{
    
    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(StartpageView.class);
        
    // UI
    private VerticalLayout layout;
    private Embedded logo;
    private Label untertitel;
    private Label hda;
    private Label trenner;
    private VerticalLayout suchBox;
    private Label infoTxt;
    private SearchComponent sucheLeiste;

    public StartpageView() {
        super();
        setCompositionRoot(buildContent());
    }
    
    private Component buildContent() {
        layout = new VerticalLayout();
        layout.setSizeFull();
        
        // Logo
        // Normal ist ExternalResource zu verwenden, wegen dem Servlet-Mapping in der web.xml aber nicht moeglich
        logo = new Embedded(null, new ImgThemeResource("JeMiNa"));
        logo.setAlternateText(locale.localize("jemina"));
        layout.addComponent(logo);
        layout.setComponentAlignment(logo, Alignment.MIDDLE_CENTER);
                
        // Untertitel
        untertitel = new Label(locale.localize("subtitel"));
        untertitel.setStyleName("h3");
        layout.addComponent(untertitel);
        
        // HDA
        hda = new Label(locale.localize("hda"));
        hda.setStyleName("h2");
        layout.addComponent(hda);
        
        // Trenner
        trenner = new Label("<hr/>");
        trenner.setContentMode(Label.CONTENT_XHTML);
        trenner.setWidth(100F, UNITS_PERCENTAGE);
        layout.addComponent(trenner);
        
        // Such-Box
        suchBox = new VerticalLayout();
        suchBox.setSizeFull();
        layout.addComponent(suchBox);
        layout.setMargin(true);
        layout.setExpandRatio(suchBox, 100F);
        
        infoTxt = new Label(locale.localize("hilfetext"), Label.CONTENT_XHTML);
        infoTxt.setStyleName("hilfetext");
        suchBox.addComponent(infoTxt);
        
        sucheLeiste = new SearchComponent();
        sucheLeiste.focus();
                        
        suchBox.addComponent(sucheLeiste);
        suchBox.setExpandRatio(sucheLeiste, 100F);
        suchBox.setComponentAlignment(sucheLeiste, Alignment.MIDDLE_CENTER);
                
        return layout;
    }
    
    /**
     * @see Suche#setSuchListener(de.cnam.jemina.ui.components.Suche.SuchListener) 
     */
    public void setSuchListener(SearchComponent.SuchListener listener) {
        sucheLeiste.setSuchListener(listener);
    }
    
    /**
     * Kleines EasterEgg zu Revision 100
     * @param listener 
     */
    public void addEasterEgg(MouseEvents.ClickListener listener) {
        logo.addListener(listener);
    }
    
}